#include <stdio.h>
#include <stdlib.h>
#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>

#include "affichage.h"
#include "controleur.h"
#include "controleurSDL.h"

/*!
* \file affichage.c
* \brief Fichier contenant le code des fonctions liees  l'affichage par la SDL.
*/

EtatsJeu etat;
char* nom_1;
char* nom_2;


/*!
 * \fn int main_affichage()
 * \brief Fonction principale de la partie affichage, elle appelle les autres en fonction de l'etat du jeu
 *
 */
int main_affichage()
{
    nom_1="Joueur 1";
    nom_2="Joueur 2";
    etat=LANCEMENT;/*lance le jeu direct  l'ecran de lancement, sans rentrer les noms des joueurs*/
    //etat=SAISIE_JOUEURS; /*lance le jeu  l'ecran "entrer nom joueur 1"*/

    if (SDL_Init(SDL_INIT_VIDEO)<0) /*initialisation de la SDL*/
    {
        printf("Unable to init SDL: %s\n", SDL_GetError());
        exit(EXIT_FAILURE);
    }
    if(TTF_Init()==-1)  /*initialisation de SDL_ttf (affichage de texte)*/
    {
        fprintf(stderr, "Erreur d'initialisation de TTF_Init : %s\n", TTF_GetError());
        exit(EXIT_FAILURE);
    }

    while(etat!=FERMER)
    {
        switch(etat)
        {
            case SAISIE_JOUEURS:
                saisie_noms_joueurs();
                break;
            case LANCEMENT:
                affichage_ecran_accueil();
                break;
            case CONFIGURATION:
                affichage_menu_configuration();
                break;
            case TOUR_J1P1:
                printf("et la normalement ca affiche la carte");
                affichage_carte(NULL);
                break;
            default:
                break;
        }
    }
    TTF_Quit();
    SDL_Quit();
    return 0;
}


/*!
 * \fn char* afficherListeClasses(char** nomsClasses, char** skinsClasses, int nbChoix, TTF_Font* police,SDL_Color couleurTexte)
 * \brief Fonction permettant le choix de la classe d'un personnage par le joueur
 *
 * \param le tableau contenant les noms des classes, le tableau contenant les adresses de leurs images, le nombre de classes, et la police et la couleur dans lesquelles crire les noms
 * \return le nom de la classe choisie (ou "fermer" si l'utilisateur ferme la fenetre)
 */
char* afficherListeClasses(char** nomsClasses, char** skinsClasses, int nbChoix, TTF_Font* police,SDL_Color couleurTexte)
{
    int i, quitter;
    char* classeChoisie;
    SDL_Surface* fenetre=NULL;
    SDL_Event event;
    SDL_Surface* tabTextes[nbChoix];
    SDL_Surface* tabSkins[nbChoix];
    SDL_Rect positionsTextes[nbChoix];
    SDL_Rect positionsSkins[nbChoix];
    SDL_Color couleurNoire = {0, 0, 0};

    for(i=0;i<nbChoix;i++){
        tabSkins[i]=SDL_LoadBMP(skinsClasses[i]);
        if (!tabSkins[i])
        {
            printf("Unable to load bitmap: %s\n", skinsClasses[i]);
            return NULL;
        }
        SDL_SetColorKey(tabSkins[i], SDL_SRCCOLORKEY, SDL_MapRGB(tabSkins[i]->format, 0, 0, 255));
    }

    fenetre = SDL_SetVideoMode(260, nbChoix*tabSkins[0]->h, 32, SDL_HWSURFACE|SDL_DOUBLEBUF|SDL_RESIZABLE);
    SDL_FillRect(fenetre,NULL,SDL_MapRGB(fenetre->format,0,0,0));

    quitter=0;
    while(quitter==0)
    {
        SDL_WaitEvent(&event);
        switch(event.type)
        {
            case SDL_QUIT:
                SDL_FreeSurface(fenetre);
                return "fermer";
                break;
            case SDL_MOUSEBUTTONDOWN:
                for(i=0;i<nbChoix;i++)
                    {
                        if(event.button.y/positionsSkins[0].h==i)
                        {
                            classeChoisie=nomsClasses[i];
                            quitter=1;
                        }
                    }
                break;
            default:
                break;
        }
        for(i=0;i<nbChoix;i++)
        {
            tabTextes[i]=TTF_RenderText_Shaded(police, nomsClasses[i], couleurTexte,couleurNoire);
            positionsSkins[i].y=i*tabSkins[0]->h;
            positionsSkins[i].x=0;
            positionsTextes[i].x=tabSkins[i]->w+4;
            positionsTextes[i].y=positionsSkins[i].y+(tabSkins[i]->h/3);
            SDL_BlitSurface(tabTextes[i],NULL,fenetre,&positionsTextes[i]);
            SDL_BlitSurface(tabSkins[i],NULL,fenetre,&positionsSkins[i]);
        }
        SDL_Flip(fenetre);
    }
    for(i=0;i<nbChoix;i++)
    {
        SDL_FreeSurface(tabTextes[i]);
        SDL_FreeSurface(tabSkins[i]);
    }
    SDL_FreeSurface(fenetre);
    return classeChoisie;
}


/*!
 * \fn int saisie_noms_joueurs()
 * \brief fonction qui gre l'affichage de l'ecran de saisie des noms des joueurs
 */
int saisie_noms_joueurs()
{
    SDL_Surface* ecran=NULL;
    SDL_Surface* logo = NULL;
    SDL_Surface* texte = NULL;
    SDL_Rect pos_logo;
    SDL_Rect pos_texte;
    TTF_Font *police = NULL;

    SDL_Color couleurNoire = {0, 0, 0};
    SDL_Color couleurBlanche = {255, 255, 255};

    etat=SAISIE_JOUEURS;
    police=TTF_OpenFont("../resources/fonts/arial.ttf",26);

    ecran = SDL_SetVideoMode(LARGEUR_CARTE*(LARGEUR_CASE+1), HAUTEUR_CARTE*(HAUTEUR_CASE+2), 32, SDL_HWSURFACE|SDL_DOUBLEBUF);
    if (ecran == NULL) // Si l'ouverture a chou, on le note et on arrte
    {
        fprintf(stderr, "Impossible de charger le mode vido : %s\n", SDL_GetError());
        exit(EXIT_FAILURE);
    }
    SDL_WM_SetCaption("Elder Internal Ignition",NULL);

    texte = TTF_RenderText_Shaded(police, "Entrez le nom du joueur 1", couleurBlanche,couleurNoire);

    SDL_FillRect(ecran,NULL,SDL_MapRGB(ecran->format,0,0,0));

    logo = SDL_LoadBMP("../resources/Skins/logo.bmp");
    if (!logo)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }
    pos_logo.x=(ecran->w-logo->w)/2;
    pos_logo.y=0;
    pos_texte.x=(ecran->w-texte->w)/2;
    pos_texte.y=ecran->h-200;
    SDL_BlitSurface(texte,NULL,ecran,&pos_texte);
    SDL_BlitSurface(logo,NULL,ecran,&pos_logo);
    SDL_Flip(ecran);

    char nom_joueur1[TAILLE_NOMS] = "";
    fgets(nom_joueur1, sizeof(nom_joueur1), stdin);
    if(strlen(nom_joueur1)>TAILLE_NOMS-2){
        printf("erreur : nom trop long");
        return -1;
    }
    if(strlen(nom_joueur1)>1){ nom_joueur1[strlen(nom_joueur1)-1]=NULL;}

    char nom_joueur2[TAILLE_NOMS] = "";

    texte = TTF_RenderText_Shaded(police, "Entrez le nom du joueur 2", couleurBlanche,couleurNoire);
    SDL_BlitSurface(texte,NULL,ecran,&pos_texte);
    SDL_Flip(ecran);

    fgets(nom_joueur2, sizeof(nom_joueur2), stdin);
    if(strlen(nom_joueur1)>TAILLE_NOMS-2){
        printf("erreur : nom trop long");
        return -1;
    }
    if(strlen(nom_joueur2)>1) {nom_joueur2[strlen(nom_joueur2)-1]=NULL;}

    nom_1=nom_joueur1;
    nom_2=nom_joueur2;

    TTF_CloseFont(police);
    SDL_FreeSurface(ecran);
    SDL_FreeSurface(logo);
    SDL_FreeSurface(texte);
    return 0;
}


/*!
 * \fn int affichage_ecran_accueil()
 * \brief fonction qui gre l'affichage de l'ecran d'accueil (logo + bouton de lancement)
 */
int affichage_ecran_accueil()
{
    ajouterUnJoueur(nom_1,&etat);
    ajouterUnJoueur(nom_2,&etat);
    etat=LANCEMENT;
    SDL_Surface* ecran = SDL_SetVideoMode(LARGEUR_CARTE*(LARGEUR_CASE+1), HAUTEUR_CARTE*(HAUTEUR_CASE+2), 32, SDL_HWSURFACE|SDL_DOUBLEBUF);
    SDL_WM_SetCaption("Elder Internal Ignition",NULL);
    SDL_Event event;
    SDL_Surface* logo = NULL;
    SDL_Surface* texte = NULL;
    TTF_Font *police = NULL;
    SDL_Rect pos_logo;
    SDL_Rect pos_texte;
    SDL_Color couleurBleue = {10, 30, 80};
    SDL_Color couleurDoree = {190, 190, 120};

    police=TTF_OpenFont("../resources/fonts/OLDENGL.ttf",40);
    texte = TTF_RenderText_Shaded(police, "Entrez dans le Royaume !", couleurDoree,couleurBleue);
    pos_texte.x=(ecran->w-texte->w)/2;
    pos_texte.y=ecran->h-200;

    logo = SDL_LoadBMP("../resources/Skins/logo.bmp");
    if (!logo)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }
    pos_logo.x=(ecran->w-logo->w)/2;
    pos_logo.y=0;
    SDL_FillRect(ecran,NULL,SDL_MapRGB(ecran->format,0,0,0));
    SDL_BlitSurface(logo,NULL,ecran,&pos_logo);
    SDL_BlitSurface(texte,NULL,ecran,&pos_texte);
    SDL_Flip(ecran);

    while(etat==LANCEMENT)
    {
        SDL_WaitEvent(&event);
        switch(event.type)
        {
            case SDL_QUIT:
                etat=FERMER;
                break;
            case SDL_MOUSEBUTTONDOWN:
                if (event.button.x<pos_texte.x+texte->w&&event.button.x>pos_texte.x&&event.button.y<pos_texte.y+texte->h&&event.button.y>pos_texte.y)
                    {etat=CONFIGURATION;}
                break;
            default:
                break;
        }
        SDL_BlitSurface(logo,NULL,ecran,&pos_logo);
        SDL_BlitSurface(texte,NULL,ecran,&pos_texte);
        SDL_Flip(ecran);
    }
    TTF_CloseFont(police);
    SDL_FreeSurface(ecran);
    SDL_FreeSurface(logo);
    SDL_FreeSurface(texte);
    return 0;
}


/*!
 * \fn int affichage_menu_configuration()
 * \brief fonction qui gre l'affichage de l'ecran de configuration de la partie (choix de la carte et des personnages)
 */
int affichage_menu_configuration()
{
    etat=CONFIGURATION;
    int nombre_classes=nbClasses();
    SDL_Surface* ecran = SDL_SetVideoMode(LARGEUR_CARTE*(LARGEUR_CASE+1), HAUTEUR_CARTE*(HAUTEUR_CASE+2), 32, SDL_HWSURFACE|SDL_DOUBLEBUF);
    SDL_WM_SetCaption("Elder Internal Ignition",NULL);
    SDL_Event event;
    SDL_Surface* lancer_partie = NULL;
    SDL_Surface* map_choisie = NULL;
    SDL_Surface* texte = NULL;
    SDL_Surface* texte2 = NULL;
    SDL_Surface* texte3 = NULL;
    SDL_Surface* previsualisation[5]={NULL};
    SDL_Surface* textes[NB_JOUEURS*NB_PERSO]={NULL};
    SDL_Surface* images_classes[nombre_classes];
    SDL_Surface* images_persos[NB_PERSO][NB_JOUEURS]={{NULL}};
    SDL_Rect positions_images[NB_PERSO][NB_JOUEURS];
    SDL_Rect posTextes[NB_JOUEURS*NB_PERSO];
    SDL_Rect pos_bouton;
    SDL_Rect pos_texte;
    SDL_Rect pos_texte2;
    SDL_Rect pos_texte3;
    SDL_Rect pos_texte3_bis;
    SDL_Rect position_carte[5];
    TTF_Font *police = NULL;
    TTF_Font *petite_police = NULL;
    SDL_Color couleurNoire = {0, 0, 0};
    SDL_Color couleurBlanche = {255, 255, 255};
    SDL_Color couleurBleue = {10, 30, 80};
    SDL_Color couleurDoree = {190, 190, 120};
    int i,j,p,k,c;

    SDL_FillRect(ecran,NULL,SDL_MapRGB(ecran->format,0,0,0));

    police=TTF_OpenFont("../resources/fonts/OLDENGL.ttf",46);
    petite_police=TTF_OpenFont("../resources/fonts/OLDENGL.ttf",32);

    lancer_partie= TTF_RenderText_Shaded(police, "Lancer la partie", couleurDoree, couleurBleue);
    pos_bouton.y=ecran->h-lancer_partie->h-25;
    pos_bouton.x=(ecran->w-lancer_partie->w)/2;
    texte= TTF_RenderText_Shaded(police, nom_1, couleurBlanche,couleurNoire);
    texte2= TTF_RenderText_Shaded(police, nom_2, couleurBlanche, couleurNoire);
    texte3= TTF_RenderText_Shaded(petite_police, "choisissez vos personnages", couleurBlanche, couleurNoire);
    pos_texte.x=ecran->w/4-texte->w/2;
    pos_texte.y=10;
    pos_texte2.x=(3*ecran->w)/4-texte2->w/2;
    pos_texte2.y=10;
    pos_texte3.x=pos_texte.x-(texte3->w-texte->w)/2;
    pos_texte3.y=pos_texte.y+(3*texte3->h)/2;
    pos_texte3_bis.x=pos_texte2.x-(texte3->w-texte2->w)/2;
    pos_texte3_bis.y=pos_texte2.y+(3*texte3->h)/2;

    SDL_BlitSurface(texte,NULL,ecran,&pos_texte);
    SDL_BlitSurface(texte2,NULL,ecran,&pos_texte2);
    SDL_BlitSurface(texte3,NULL,ecran,&pos_texte3);
    SDL_BlitSurface(texte3,NULL,ecran,&pos_texte3_bis);

    police=TTF_OpenFont("../resources/fonts/arial.ttf",26);

    char src[50], dest[50];
    char buffer[2];
    for(i=0;i<NB_PERSO;i++)
    {
        strcpy(dest,  "personnage ");
        strcpy(src, itoa(i+1,buffer,10));
        textes[i]= TTF_RenderText_Shaded(police, strcat(dest, src), couleurBlanche,couleurNoire);
        posTextes[i].x=ecran->w/4-textes[i]->w/2;
        posTextes[i].y=(i+1)*ecran->h/6;
        SDL_BlitSurface(textes[i],NULL,ecran,&(posTextes[i]));
    }
    for(i=NB_PERSO;i<NB_JOUEURS*NB_PERSO;i++)
    {
        strcpy(dest,  "personnage ");
        strcpy(src, itoa(i-NB_PERSO+1,buffer,10));
        textes[i]= TTF_RenderText_Shaded(police, strcat(dest, src), couleurBlanche,couleurNoire);
        posTextes[i].x=(3*ecran->w)/4-textes[i]->w/2;
        posTextes[i].y=posTextes[i-NB_PERSO].y;
        SDL_BlitSurface(textes[i],NULL,ecran,&posTextes[i]);
    }

    char** path_images=obtenirSkinsClasses();
    int numClassePerso[NB_PERSO][NB_JOUEURS]={{-1,-1},{-1,-1},{-1,-1}};
    j=0; /*numero du joeuur*/
    p=0; /*numero du personnage*/
    char *classeChoisie;
    for(i=0;i<nombre_classes;i++)
    {
        images_classes[i]=SDL_LoadBMP(path_images[i]);
        if (!images_classes[i])
        {
            printf("Unable to load bitmap: %s\n", SDL_GetError());
            return 1;
        }
        SDL_SetColorKey(images_classes[i], SDL_SRCCOLORKEY, SDL_MapRGB(images_classes[i]->format, 0, 0, 255));
    }

    map_choisie=SDL_LoadBMP("../resources/Skins/Map_select.bmp");
    if (!map_choisie)
        {
            printf("Unable to load bitmap: %s\n", SDL_GetError());
            return 1;
        }
    SDL_SetColorKey(map_choisie, SDL_SRCCOLORKEY, SDL_MapRGB(map_choisie->format, 0, 0, 255));

    char* path[5];
    path[0]="../resources/Skins/Map_1.bmp";        //a revoir : cela peut se trouver dans le XML
    path[1]="../resources/Skins/Map_2.bmp";
    path[2]="../resources/Skins/Map_3.bmp";
    path[3]="../resources/Skins/Map_4.bmp";
    path[4]="../resources/Skins/autre_map.bmp";

    for(i=0;i<5;i++)
    {
        previsualisation[i]=SDL_LoadBMP(path[i]);
        if (!previsualisation[i])
        {
            printf("Unable to load bitmap: %s\n", SDL_GetError());
            return 1;
        }
        position_carte[i].y=(ecran->h)-(previsualisation[i]->h+100);
        position_carte[i].x=(ecran->w-previsualisation[i]->w)/2+(10+previsualisation[i]->w)*(i-2);
    }
    SDL_Flip(ecran);

    c=-1; /*le numro de la carte choisie*/
    while(etat==CONFIGURATION)
    {
        SDL_WaitEvent(&event);
        switch(event.type)
        {
            case SDL_QUIT:
                etat=FERMER;
                return 0;
                break;
            case SDL_MOUSEBUTTONDOWN:
                if(event.button.x>pos_bouton.x&&event.button.x<pos_bouton.x+lancer_partie->w&&event.button.y>pos_bouton.y&&event.button.y<pos_bouton.y+lancer_partie->h){
                    for(i=0;i<NB_PERSO;i++){
                        for(k=0;k<NB_JOUEURS;k++){
                            if(numClassePerso[i][k]==-1){
                                p=-1;
                            }
                        }
                    }
                    if(p==0&&c!=-1){
                        etat=TOUR_J1P1;
                    }
                    if(c==-1){
                        printf("choisissez une carte\n");
                    }
                    if(p==-1){
                        p=0;
                        printf("selectionnez des personnages\n");
                    }
                }
                for(i=0;i<5;i++)
                {
                    if(event.button.x>position_carte[i].x&&event.button.x<position_carte[i].x+previsualisation[0]->w&&event.button.y>position_carte[i].y&&event.button.y<position_carte[i].y+previsualisation[0]->h)
                    {
                        c=i;
                        selectionnerCarte(obtenirNomsCartes()[c]);
                    }
                }
                if(event.button.x>posTextes[0].x&&event.button.x<posTextes[0].x+textes[0]->w)
                    j=1;
                if(event.button.x>posTextes[NB_PERSO].x&&event.button.x<posTextes[NB_PERSO].x+textes[NB_PERSO]->w)
                    j=2;
                for(i=0;i<NB_PERSO;i++)
                {
                    if(event.button.y>posTextes[i].y&&event.button.y<posTextes[i].y+textes[i]->h)
                        p=i+1;
                }
                if(j!=0&&p!=0)
                {
                    classeChoisie=afficherListeClasses(obtenirNomsClasses(), obtenirSkinsClasses(), nombre_classes, police, couleurBlanche);
                    if(classeChoisie!="fermer")
                    {
                        numClassePerso[p-1][j-1]=ajouterPersonnage(classeChoisie, p-1, j);
                    }
                    ecran = SDL_SetVideoMode(LARGEUR_CARTE*(LARGEUR_CASE+1), HAUTEUR_CARTE*(HAUTEUR_CASE+2), 32, SDL_HWSURFACE|SDL_DOUBLEBUF);
                }
                break;
            default:
                break;
        }
        for(i=0;i<NB_JOUEURS*NB_PERSO;i++)
        {
            SDL_BlitSurface(textes[i],NULL,ecran,&(posTextes[i]));
        }
        for(i=0;i<NB_PERSO;i++){
            for(k=0;k<NB_JOUEURS;k++){
                positions_images[i][k].y=posTextes[i].y+textes[i]->h;
                positions_images[i][k].x=posTextes[NB_PERSO*k].x+(textes[NB_PERSO*k]->w-images_classes[0]->w)/2;
                images_persos[i][k]=images_classes[numClassePerso[i][k]];
                if(numClassePerso[i][k]!=-1)
                {
                    SDL_BlitSurface(images_persos[i][k],NULL,ecran,&positions_images[i][k]);
                }
            }
        }
        SDL_BlitSurface(lancer_partie,NULL,ecran,&pos_bouton);
        SDL_BlitSurface(texte,NULL,ecran,&pos_texte);
        SDL_BlitSurface(texte2,NULL,ecran,&pos_texte2);
        SDL_BlitSurface(texte3,NULL,ecran,&pos_texte3);
        SDL_BlitSurface(texte3,NULL,ecran,&pos_texte3_bis);
        for(i=0;i<5;i++)
        {
            SDL_BlitSurface(previsualisation[i],NULL,ecran,&position_carte[i]);
        }
        if(c!=-1) SDL_BlitSurface(map_choisie,NULL,ecran,&position_carte[c]);
        SDL_Flip(ecran);
        p=0;
        j=0;
    }

    TTF_CloseFont(police);
    TTF_CloseFont(petite_police);
    SDL_FreeSurface(ecran);
    SDL_FreeSurface(map_choisie);
    SDL_FreeSurface(texte);
    SDL_FreeSurface(texte2);
    SDL_FreeSurface(texte3);
    SDL_FreeSurface(lancer_partie);
    for(i=0;i<5;i++){
        SDL_FreeSurface(previsualisation[i]);
    }
    for(i=0;i<NB_PERSO*NB_JOUEURS;i++){
        SDL_FreeSurface(textes[i]);
    }
    for(i=0;i<nombre_classes;i++){
        SDL_FreeSurface(images_classes[i]);
    }
    return 0;
}


/*!
 * \fn int affichage_carte(char* Map)
 * \brief fonction qui gre l'affichage pendant la partie
 *
 * \param la carte au format texte (une lettre = une case)
 */

int affichage_carte(char* Map)
{
    int i,j,affichermenu;
    SDL_Surface* ecran=NULL;
    SDL_Event event;
    SDL_Surface* guerrier=NULL;
    SDL_Surface* mage=NULL;
    SDL_Surface* voleur=NULL;
    SDL_Surface* archer=NULL;
    SDL_Surface* guerisseur=NULL;
    SDL_Surface* plaine=NULL;
    SDL_Surface* eau=NULL;
    SDL_Surface* montagne=NULL;
    SDL_Surface* foret=NULL;
    SDL_Surface* bouton_continuer=NULL;
    SDL_Surface* bouton_quitter=NULL;
    SDL_Surface* Case_brillante=NULL;
    SDL_Surface* Guerrier_select=NULL;
    SDL_Rect Position_Case[LARGEUR_CARTE*HAUTEUR_CARTE];
    SDL_Rect Position_Perso[NB_PERSO];
    SDL_Rect Position_Case_brillante;
    SDL_Rect Position_Guerrier_select;
    SDL_Rect pos_bouton_continuer;
    SDL_Rect pos_bouton_quitter;
    int x_case_brillante;
    int y_case_brillante;
    int x_guerrier_select;
    int y_guerrier_select;
    int quitter=0;
    affichermenu=0;

    if ( SDL_Init( SDL_INIT_VIDEO ) < 0 )
    {
        printf( "Unable to init SDL: %s\n", SDL_GetError() );
        return 1;
    }

    ecran = SDL_SetVideoMode(LARGEUR_CARTE*(LARGEUR_CASE+1), HAUTEUR_CARTE*(HAUTEUR_CASE+2), 32, SDL_HWSURFACE|SDL_DOUBLEBUF);
    if (ecran == NULL) // Si l'ouverture a chou, on le note et on arrte
    {
        fprintf(stderr, "Impossible de charger le mode vido : %s\n", SDL_GetError());
        exit(EXIT_FAILURE);
    }

    SDL_WM_SetCaption("Elder Internal Ignition",NULL);

    pos_bouton_quitter.x=(LARGEUR_CARTE*LARGEUR_CASE-LARGEUR_BOUTON)/2;
    pos_bouton_continuer.x=(LARGEUR_CARTE*LARGEUR_CASE-LARGEUR_BOUTON)/2;
    pos_bouton_quitter.y=(HAUTEUR_CARTE*HAUTEUR_CASE-HAUTEUR_BOUTON)/2+HAUTEUR_BOUTON;
    pos_bouton_continuer.y=(HAUTEUR_CARTE*HAUTEUR_CASE-HAUTEUR_BOUTON)/2-HAUTEUR_BOUTON;

    guerrier = SDL_LoadBMP("../resources/Skins/guerrier.bmp");
    if (!guerrier)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }
    SDL_SetColorKey(guerrier, SDL_SRCCOLORKEY, SDL_MapRGB(guerrier->format, 0, 0, 255));

    bouton_continuer = SDL_LoadBMP("../resources/Skins/continuer.bmp");
    if (!bouton_continuer)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }

    bouton_quitter = SDL_LoadBMP("../resources/Skins/quitter.bmp");
    if (!bouton_continuer)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }

    mage = SDL_LoadBMP("../resources/Skins/mage.bmp");
    if (!mage)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }
    SDL_SetColorKey(mage, SDL_SRCCOLORKEY, SDL_MapRGB(mage->format, 0, 0, 255));

    voleur = SDL_LoadBMP("../resources/Skins/voleur.bmp");
    if (!voleur)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }
    SDL_SetColorKey(voleur, SDL_SRCCOLORKEY, SDL_MapRGB(voleur->format, 0, 0, 255));


    archer = SDL_LoadBMP("../resources/Skins/archer.bmp");
    if (!archer)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }
    SDL_SetColorKey(archer, SDL_SRCCOLORKEY, SDL_MapRGB(archer->format, 0, 0, 255));

    guerisseur = SDL_LoadBMP("../resources/Skins/guerisseur.bmp");
    if (!guerisseur)
    {
        printf("Unable to load bitmap: %s\n", SDL_GetError());
        return 1;
    }
    SDL_SetColorKey(guerisseur, SDL_SRCCOLORKEY, SDL_MapRGB(guerisseur->format, 0, 0, 255));

    plaine = SDL_LoadBMP("../resources/Skins/plaine.bmp");
    if (!plaine)
        {
            printf("Unable to load bitmap: %s\n", SDL_GetError());
            return 1;
        }
    SDL_SetColorKey(plaine, SDL_SRCCOLORKEY, SDL_MapRGB(plaine->format, 0, 0, 255));

    eau = SDL_LoadBMP("../resources/Skins/eau.bmp");
    if (!eau)
        {
            printf("Unable to load bitmap: %s\n", SDL_GetError());
            return 1;
        }
    SDL_SetColorKey(eau, SDL_SRCCOLORKEY, SDL_MapRGB(eau->format, 0, 0, 255));

    montagne = SDL_LoadBMP("../resources/Skins/montagne.bmp");
    if (!montagne)
        {
            printf("Unable to load bitmap: %s\n", SDL_GetError());
            return 1;
        }
    SDL_SetColorKey(montagne, SDL_SRCCOLORKEY, SDL_MapRGB(montagne->format, 0, 0, 255));

    foret = SDL_LoadBMP("../resources/Skins/foret.bmp");
    if (!foret)
        {
            printf("Unable to load bitmap: %s\n", SDL_GetError());
            return 1;
        }
    SDL_SetColorKey(foret, SDL_SRCCOLORKEY, SDL_MapRGB(foret->format, 0, 0, 255));

    Case_brillante = SDL_LoadBMP("../resources/Skins/case_brillante.bmp");
                    if (!Case_brillante)
                    {
                        printf("Unable to load bitmap: %s\n", SDL_GetError());
                        return 1;
                    }
    SDL_SetColorKey(Case_brillante, SDL_SRCCOLORKEY, SDL_MapRGB(Case_brillante->format, 0, 0, 255));

    Guerrier_select = SDL_LoadBMP("../resources/Skins/guerrier_select.bmp");
                    if (!Guerrier_select)
                    {
                        printf("Unable to load bitmap: %s\n", SDL_GetError());
                        return 1;
                    }
    SDL_SetColorKey(Guerrier_select, SDL_SRCCOLORKEY, SDL_MapRGB(Guerrier_select->format, 0, 0, 255));

    for(i=0;i<LARGEUR_CARTE;i+=2)
    {
        for(j=0;j<HAUTEUR_CARTE;j++)
            {
                Position_Case[j*LARGEUR_CARTE+i].x=LARGEUR_CASE*i;
                Position_Case[j*LARGEUR_CARTE+i].y=HAUTEUR_CASE*j;
            }
    }
    for(i=1;i<LARGEUR_CARTE;i+=2)
    {
        for(j=0;j<HAUTEUR_CARTE;j++)
            {
                Position_Case[j*LARGEUR_CARTE+i].x=LARGEUR_CASE*i;
                Position_Case[j*LARGEUR_CARTE+i].y=HAUTEUR_CASE*j+(HAUTEUR_CASE/2);
            }
    }

    init_controleur(Position_Case);

    while(quitter==0)
    {
        SDL_WaitEvent(&event);
        if(affichermenu==1){
            switch(event.type) /* Test du type d'vnement */
            {
                case SDL_QUIT: /* Si c'est un vnement de type "Quitter" */
                    quitter=1;
                    break;
                case SDL_MOUSEBUTTONDOWN:
                    if(pos_bouton_continuer.x<event.button.x&&event.button.x<pos_bouton_continuer.x+LARGEUR_BOUTON){
                        if(pos_bouton_continuer.y<event.button.y&&event.button.y<pos_bouton_continuer.x+HAUTEUR_BOUTON){
                            affichermenu=0;
                        }
                        if(pos_bouton_quitter.y<event.button.y&&event.button.y<pos_bouton_quitter.x+HAUTEUR_BOUTON){
                            quitter=1;
                        }
                    }
                    break;
                case SDL_KEYDOWN:/* Si c'est un vnement de type "touche presse" */
                    switch(event.key.keysym.sym){
                        case SDLK_ESCAPE:
                            affichermenu=0;
                            break;
                        default:
                            quitter=0;
                    }
                break;
            }
        }
        else{
            switch(event.type) /* Test du type d'vnement */
            {
                case SDL_QUIT: /* Si c'est un vnement de type "Quitter" */
                    quitter=1;
                    break;
                case SDL_MOUSEBUTTONDOWN:
                    deplacement_personnage(event.button.x,event.button.y);
                    break;
                case SDL_MOUSEMOTION:
                    if(event.motion.x<LARGEUR_CARTE*LARGEUR_CASE&&event.motion.y<HAUTEUR_CARTE*HAUTEUR_CASE)
                    {
                        x_case_brillante = get_position_case_x(deplacement_brillance(event.motion.x,event.motion.y));
                        y_case_brillante = get_position_case_y(deplacement_brillance(event.motion.x,event.motion.y));
                    }
                    break;
                case SDL_KEYDOWN:/* Si c'est un vnement de type "touche presse" */
                    switch(event.key.keysym.sym){
                        case SDLK_n:
                            persosuivant();
                            break;
                        case SDLK_ESCAPE:
                            affichermenu=1;
                            break;
                        default:
                            quitter=0;
                    }
                break;
            }
        }
        for(i=0;i<NB_PERSO;i++){
            Position_Perso[i].x=get_position_perso_x(i);
            Position_Perso[i].y=get_position_perso_y(i);
        }
        Position_Case_brillante.x=x_case_brillante;
        Position_Case_brillante.y=y_case_brillante;
        x_guerrier_select = get_position_case_x(&Position_Perso[persoactuel()]);
        y_guerrier_select = get_position_case_y(&Position_Perso[persoactuel()]);
        Position_Guerrier_select.x=x_guerrier_select;
        Position_Guerrier_select.y=y_guerrier_select;
        SDL_FillRect(ecran,NULL,SDL_MapRGB(ecran->format,0,0,0));
        if(affichermenu==0)
        {
           for(i=0;i<LARGEUR_CARTE*HAUTEUR_CARTE;i++)
            {
                switch(Map[i])
                {
                    case 80: //"P" en ASCII
                        SDL_BlitSurface(plaine,NULL,ecran,&Position_Case[i]);
                        break;
                    case 70: //"F" en ASCII
                        SDL_BlitSurface(foret,NULL,ecran,&Position_Case[i]);
                        break;
                    case 69: //"E" en ASCII
                        SDL_BlitSurface(eau,NULL,ecran,&Position_Case[i]);
                        break;
                    case 77: //"M" en ASCII
                        SDL_BlitSurface(montagne,NULL,ecran,&Position_Case[i]);
                        break;
                    default:
                        quitter=0;
                }

            }
           // for(i=0;i<NB_PERSO;i++)
           // {
                SDL_BlitSurface(guerisseur,NULL,ecran,&Position_Perso[0]);
                SDL_BlitSurface(mage,NULL,ecran,&Position_Perso[1]);
                SDL_BlitSurface(guerrier,NULL,ecran,&Position_Perso[2]);

           // }
            SDL_BlitSurface(Guerrier_select,NULL,ecran,&Position_Guerrier_select);
            SDL_BlitSurface(Case_brillante,NULL,ecran,&Position_Case_brillante);
        }else{
            SDL_BlitSurface(bouton_continuer,NULL,ecran,&pos_bouton_continuer);
            SDL_BlitSurface(bouton_quitter,NULL,ecran,&pos_bouton_quitter);
        }

        SDL_Flip(ecran);
    }
    quitter=0;
    SDL_FreeSurface(guerrier);
    SDL_FreeSurface(Case_brillante);
    SDL_FreeSurface(Guerrier_select);
    SDL_FreeSurface(plaine);
    SDL_FreeSurface(mage);
    SDL_FreeSurface(voleur);
    SDL_FreeSurface(archer);
    SDL_FreeSurface(guerisseur);
    SDL_FreeSurface(eau);
    SDL_FreeSurface(montagne);
    SDL_FreeSurface(foret);
    SDL_Quit();
    return 0;
}


